@@ -25,13 +25,14 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include "exchange-delegates.h"
 #include "exchange-delegates-user.h"
 
 #include <shell/e-shell.h>
 #include <mail/mail-ops.h>
 #include <mail/mail-send-recv.h>
-#include <mail/e-mail-local.h>
 #include <mail/e-mail-folder-utils.h>
 #include <exchange-account.h>
 #include <e2k-global-catalog.h>
